@@ -24,6 +24,7 @@
 #include <Lum/Panel.h>
 #include <Lum/TextValue.h>
 
+#include "Configuration.h"
 #include "FunctionInput.h"
 #include "Util.h"
 
@@ -50,7 +51,7 @@ void Calc::Calculate()
       history->Prepend(calcInput->Get());
     }
 
-    expression->Calculate(value,result);
+    expression->Calculate(value,result,(Parser::TrigonometryMode)calcTrigoMode->Get());
 
     this->calcResult->Set(DoubleToWStringFloat(value));
 
@@ -119,3 +120,29 @@ void Calc::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
   Lum::Component::Resync(model,msg);
 }
 
+void Calc::LoadConfig(Lum::Config::Node *top)
+{
+  for (Lum::Config::Node::NodeList::const_iterator iter=top->GetChildren().begin();
+       iter!=top->GetChildren().end();
+       ++iter) {
+    Lum::Config::Node *node=*iter;
+
+    if (node->GetName()==L"calculator") {
+      size_t mode;
+
+      if (node->GetAttribute(L"trigometricalMode",mode)) {
+        calcTrigoMode->Set(mode);
+      }
+    }
+  }
+}
+
+void Calc::StoreConfig(Lum::Config::Node *top)
+{
+  Lum::Config::Node *node;
+
+  node=new Lum::Config::Node(L"calculator");
+  node->SetAttribute(L"trigometricalMode",*calcTrigoMode);
+
+  top->Add(node);
+}
