@@ -190,27 +190,27 @@ Lum::Object* FunctionsDialog::GetContent()
 
   horiz=Lum::HPanel::Create(true,true);
 
-  horiz->Add(Lum::VPanel::Create(false,true)
-             ->Add(Lum::Button::Create(L"_Add",addAction,true,false))
-             ->Add(Lum::Button::Create(L"_Modify",updateAction,true,false))
-             ->Add(Lum::Button::Create(L"_Remove",removeAction,true,false)));
-
-  horiz->AddSpace();
-
   headerModel=new Lum::Model::HeaderImpl();
-  headerModel->AddColumn(L"Function",Lum::Base::Size::pixel,32000);
+  headerModel->AddColumn(L"Function",Lum::Base::Size::stdCharWidth,30);
 
   table=new Lum::Table();
   table->SetFlex(true,true);
   table->SetMinWidth(Lum::Base::Size::stdCharWidth,30);
   table->GetTableView()->SetMinHeight(Lum::Base::Size::stdCharHeight,6);
-  table->SetShowHeader(true);
-  //table->GetTableView()->SetAutoHFit(true);
+  table->GetTableView()->SetAutoFitColumns(true);
+  table->SetShowHeader(false);
   table->SetModel(functions);
   table->SetHeaderModel(headerModel);
   table->SetSelection(selection);
   horiz->Add(table);
 
+  horiz->AddSpace();
+
+  horiz->Add(Lum::VPanel::Create(false,true)
+             ->Add(Lum::Button::Create(L"_Add",addAction,true,false))
+             ->Add(Lum::Button::Create(L"_Modify",updateAction,true,false))
+             ->Add(Lum::Button::Create(L"_Remove",removeAction,true,false)));
+
   return horiz;
 }
 
@@ -469,13 +469,14 @@ Plot::Plot()
   autosize(new Lum::Model::Action()),
   region(new Lum::Model::Action())
  {
-  plotVar=parser.AddVariable("x",0.0);
+   plotVar=parser.AddVariable("x",0.0);
 
-  functions=new Functions(plotVar);
+   functions=new Functions(plotVar);
+   functions->SetEmptyText(L"(No functions defined)");
 
-  Observe(editFunctions);
-  Observe(autosize);
-  Observe(region);
+   Observe(editFunctions);
+   Observe(autosize);
+   Observe(region);
 }
 
 void Plot::EditFunctions()
